"use strict";(self.webpackChunkdatabrix_hub_extension=self.webpackChunkdatabrix_hub_extension||[]).push([[509],{509:(e,t,o)=>{o.r(t),o.d(t,{default:()=>r});var n=o(974),a=o(607),i=o(605);const r={id:"databrix-hub-extension:connectionlost",description:"Provides a service to be notified when the connection to the hub server is lost.",requires:[n.JupyterFrontEnd.IPaths,i.ITranslator],optional:[n.JupyterLab.IInfo],activate:(e,t,o,n)=>{const i=o.load("jupyterlab");return async(e,t)=>{const o=await(0,a.showDialog)({title:i.__("Server unavailable or unreachable"),body:i.__("Your server is not running.\nYou have been inactive for a long time, or Jupyterhub has shut down your server.\nPlease Login again!"),buttons:[a.Dialog.okButton({label:i.__("Homepage")}),a.Dialog.cancelButton({label:i.__("Dismiss")})]});n&&(n.isConnected=!0),o.button.accept&&(window.location.href="www.databrix.org")}},autoStart:!0,provides:n.IConnectionLost}}}]);